AsyncStorable

Trait AsyncStorable 

pub trait AsyncStorable:
    Clone
    + Send
    + Sync
    + Debug
    + Unpin
    + 'static { }
A trait for types that can be held in a collection used in an asynchronous context, which might be shared between many tasks. A blanket implementation is provided.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Clone + Send + Sync + Unpin + Debug + 'static> AsyncStorable for T